require 'minitest/unit'

class WSColor
  attr_reader :io

  def initialize io
    @io = io
  end

  def print o
    case o
    when '.'
      io.print "\e[32m#{o}\e[0m"
    when 'E'
      io.print "\e[33m#{o}\e[0m"
    when 'F'
      io.print "\e[31m#{o}\e[0m"
    end
  end

  def puts *a
    output = a.collect do |out|
      case out
      when /(0 failures, 0 errors, 0 skips)/
        out.sub($&, "\e[32m#{$&}\e[0m")
      when /(\d+ failures), (\d+ errors), (\d+ skips)/
        md = $~
        out.sub(md[1], "\e[31m#{md[1]}\e[0m").sub(md[2], "\e[33m#{md[2]}\e[0m").sub(md[3], "\e[36m#{md[3]}\e[0m")
      when /Failure/
        out.sub(out, "\e[31m#{out}\e[0m")
      when /Error/
        out.sub(out, "\e[33m#{out}\e[0m")
      when /Skipped/
        out.sub(out, "\e[36m#{out}\e[0m")
      else
        out
      end
    end
    io.puts *output
  end

  def method_missing msg, *args
    io.send(msg, *args)
  end
end

MiniTest::Unit.output = WSColor.new(MiniTest::Unit.output)
